/**
 * @file
 * Provides Outlayer Masonry loader.
 */

(function (Drupal, drupalSettings, Masonry, _db) {

  'use strict';

  /**
   * Outlayer utility functions.
   *
   * @namespace
   */
  Drupal.outLayer.masonry = _db.extend({}, Drupal.outLayer || {});

  /**
   * Outlayer utility functions.
   *
   * @param {HTMLElement} grid
   *   The Outlayer HTML element.
   */
  function doOutLayerMasonry(grid) {
    var me = Drupal.outLayer.masonry;
    var opts = _db.parse(grid.getAttribute('data-outlayer-masonry')) || {};
    var $items = grid.querySelectorAll('.gridstack__box:not(.is-nixbox)');

    me.$el = grid;

    // Prepare and define aspect ratio before laying out.
    me.prepare();
    me.updateRatio($items);
    me.cleanUp();

    // Pass data to Drupal.outLayer.masonry for easy reference.
    me.$instance = new Masonry(grid, opts);
    grid.classList.add('outlayer--masonry--on');
  }

  /**
   * Attaches Outlayer behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.outLayerMasonry = {
    attach: function (context) {
      if ('length' in context) {
        context = context[0];
      }

      var elms = context.querySelectorAll('.outlayer--masonry:not(.outlayer--masonry--on)');
      if (elms.length > 0) {
        _db.once(_db.forEach(elms, doOutLayerMasonry, context));
      }
    }
  };

}(Drupal, drupalSettings, Masonry, dBlazy));
